#
# fishing.R, 30 May 21
#
# Data from:
# Alex Altair
# https://www.lesswrong.com/posts/AksEurnb73RCg9Dse/one-year-of-pomodoros-1

library("colorspace")
library("lubridate")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")

pal_col=rainbow(2)


fit_pow_law=function(df)
{
low_mod=glm(log(freq) ~ log(x), data=df, subset=(x>0 & x < 8))
print(summary(low_mod))
pred=predict(low_mod)
lines(1:7, exp(pred), col=pal_col[1])

high_mod=glm(log(freq) ~ log(x), data=df, subset=(x>7 & x < 21))
print(summary(high_mod))
pred=predict(high_mod, data.frame(x=8:20))
lines(8:20, exp(pred), col=pal_col[1])
}


end_2020=as.Date("2020-12-01")

ap=read.csv("Alex-Altair_pomodoros-per-day.csv", as.is=TRUE)
ap$date=as.Date(ap$date)
ap$days=1:nrow(ap)
ap$wday=wday(ap$date, week_start=1)

ap_2020=subset(ap, date <= end_2020)


# Daily Pomodoros worked and loess fit
pal_col=rainbow(2)
plot(ap$date, ap$poms, col=pal_col[2],
	xlab="Date", ylab="Daily Pomodoros worked")
loess_mod=loess(poms ~ days, data=ap, span=0.3)

lines(ap$date, predict(loess_mod), col=pal_col[1])


# Autocorrelation
pacf(ap$poms)

# What is the best fitting arima model?
auto.arima(ap$poms, max.order=7)


# Number of days on which a given number of Pomodoro were worked
pal_col=rainbow(3)

day_poms=count(ap$poms)
day_2020_poms=count(ap_2020$poms)
# plot(day_poms)
plot(day_poms, log="xy", col=pal_col[2],
	xlab="Pomodoro per day", ylab="Days")
points(day_2020_poms, col=pal_col[3])

legend(x="bottomleft", legend=c("2020+178 days", "2020"), bty="n",
		fill=pal_col[2:3], cex=1.2)

fit_pow_law(day_poms)
fit_pow_law(day_2020_poms)

smoothScatter(head(ap$poms, -1), tail(ap$poms, -1))

# There is serial correlation, so the following fit is
# not correct
f_poms=head(ap$poms, -1)
s_poms=tail(ap$poms, -1)

fs_mod=glm(s_poms ~ f_poms)
summary(fs_mod)

table(subset(ap, poms > 0)$wday)
table(ap$poms, ap$wday)


# Heat map of day of week Pomodoros worked
labs=c("M", "T", "W", "T", "F", "S", "S")

heatmap(table(ap$poms, ap$wday), Rowv=NA, Colv=NA, scale="none",
		labCol=NA,
		add.expr = text(x = seq_along(labs), y = -0.2,
                               labels = labs, xpd = TRUE),
		xlab="Day of week", ylab="P\no\nm\no\nd\no\nr\no\ns")

